package ocaml-version

  1. Overview
  2. Docs

Module Ocaml_version.HasSource

Test whether a release has a given feature.

Sourceval bytes : t -> bool

bytes t will return true if that release has a bytes type. Note that opam provides a bytes compatibility package for older releases.

Sourceval arch : arch -> t -> bool

arch a t will return true if architecture a is supported on release t.